@@ -24,7 +24,9 @@
 #include <QObject>
 #include <QStringList>
 
-class BugReport;
+namespace Bugzilla {
+class NewBug;
+}
 
 class BugzillaManager;
 class ProductMapping;
@@ -37,6 +39,17 @@ public:
     enum Reproducible { ReproducibleUnsure, ReproducibleNever,
         ReproducibleSometimes, ReproducibleEverytime };
 
+    enum class Backtrace {
+        Complete,
+        Reduced,
+        Exclude
+    };
+
+    enum class DrKonqiStamp {
+        Include,
+        Exclude
+    };
+
     explicit ReportInterface(QObject *parent = nullptr);
 
     void setBugAwarenessPageData(bool, Reproducible, bool, bool, bool);
@@ -56,10 +69,10 @@ public:
     void setDetailText(const QString & text);
     void setPossibleDuplicates(const QStringList & duplicatesList);
 
-    QString generateReportFullText(bool drKonqiStamp) const;
+    QString generateReportFullText(DrKonqiStamp stamp,
+                                   Backtrace inlineBacktrace) const;
 
-    BugReport newBugReportTemplate() const;
-    void sendBugReport() const;
+    Bugzilla::NewBug newBugReportTemplate() const;
 
     QStringList relatedBugzillaProducts() const;
 
@@ -90,16 +103,24 @@ public:
         return m_provideApplicationConfigurationDetails;
     }
 
+public Q_SLOTS:
+    void sendBugReport();
+
 private Q_SLOTS:
     void sendUsingDefaultProduct() const;
-    void addedToCC();
+    // Attach backtrace to bug and use collected report as comment.
+    void attachBacktraceWithReport();
     void attachSent(int);
 
 Q_SIGNALS:
     void reportSent(int);
-    void sendReportError(const QString &, const QString &);
+    void sendReportError(const QString &);
 
 private:
+    // Attach backtrace to bug. Only used internally when the comment isn't
+    // meant to be the full report.
+    void attachBacktrace(const QString &comment);
+
     QString generateAttachmentComment() const;
 
     //Information the user can provide
