@@ -76,7 +76,11 @@ QString Debugger::tryExec() const
 QStringList Debugger::supportedBackends() const
 {
     return isValid() ? m_config->group("General").readEntry("Backends")
+#if QT_VERSION < QT_VERSION_CHECK(5, 15, 0)
                                    .split(QLatin1Char('|'), QString::SkipEmptyParts) : QStringList();
+#else
+                                   .split(QLatin1Char('|'), Qt::SkipEmptyParts) : QStringList();
+#endif
 }
 
 void Debugger::setUsedBackend(const QString & backendName)
@@ -99,6 +103,12 @@ QString Debugger::backtraceBatchCommands() const
         ? m_config->group(m_backend).readPathEntry("BatchCommands", QString())
         : QString();
 }
+QString Debugger::preambleCommands() const
+{
+    return (isValid() && m_config->hasGroup(m_backend))
+        ? m_config->group(m_backend).readPathEntry("PreambleCommands", QString())
+        : QString();
+}
 
 bool Debugger::runInTerminal() const
 {
@@ -115,7 +125,7 @@ QString Debugger::backendValueOfParameter(const QString &key) const
 }
 
 //static
-void Debugger::expandString(QString & str, ExpandStringUsage usage, const QString & tempFile)
+void Debugger::expandString(QString & str, ExpandStringUsage usage, const QString & tempFile, const QString & preambleFile)
 {
     const CrashedApplication *appInfo = DrKonqi::crashedApplication();
     const QHash<QString, QString> map = {
@@ -126,6 +136,7 @@ void Debugger::expandString(QString & str, ExpandStringUsage usage, const QStrin
         { QLatin1String("signame"), appInfo->signalName() },
         { QLatin1String("pid"), QString::number(appInfo->pid()) },
         { QLatin1String("tempfile"), tempFile },
+        { QLatin1String("preamblefile"), preambleFile },
         { QLatin1String("thread"), QString::number(appInfo->thread()) },
     };
 
